pub struct HitData {
pub camera: Entity,
pub depth: f32,
pub position: Option<Vec3>,
pub normal: Option<Vec3>,
pub extra: Option<Arc<dyn HitDataExtra>>,
}Expand description
Holds data from a successful pointer hit test. See HitData::depth for important details.
Backends can attach arbitrary typed data via HitData::extra. See HitDataExtra.
Fields
camera: EntityThe camera entity used to detect this hit. Useful when you need to find the ray that was cast for this hit when using a raycasting backend.
depth: f32depth only needs to be self-consistent with other PointerHitss using the same
RenderTarget. However, it is recommended to use the
distance from the pointer to the hit, measured from the near plane of the camera, to the
point, in world space.
position: Option<Vec3>The position reported by the backend, if the data is available. Position data may be in any space (e.g. World space, Screen space, Local space), specified by the backend providing it.
normal: Option<Vec3>The normal vector of the hit test, if the data is available from the backend.
extra: Option<Arc<dyn HitDataExtra>>Optional backend-specific extra data attached to this hit. Read it with HitData::extra_as.
This is stored in an Arc so cloning HitData stays cheap. This field is excluded
from PartialEq because value equality for trait objects would require extra dynamic
downcasting that the picking pipeline does not need.
Implementations
Sourceimpl HitData
impl HitData
Sourcepub fn new(
camera: Entity,
depth: f32,
position: Option<Vec3>,
normal: Option<Vec3>,
) -> Self
pub fn new( camera: Entity, depth: f32, position: Option<Vec3>, normal: Option<Vec3>, ) -> Self
Construct a HitData.
Sourcepub fn extra_as<T: Any>(&self) -> Option<&T>
pub fn extra_as<T: Any>(&self) -> Option<&T>
Returns any attached extra data as T if available.
This returns None if no extra data was attached, or if the hit stores a
different concrete extra data type.
Sourcepub fn new_with_extra(
camera: Entity,
depth: f32,
position: Option<Vec3>,
normal: Option<Vec3>,
extra: impl HitDataExtra,
) -> Self
pub fn new_with_extra( camera: Entity, depth: f32, position: Option<Vec3>, normal: Option<Vec3>, extra: impl HitDataExtra, ) -> Self
Creates a HitData with backend-specific extra data. extra can be
any HitDataExtra.
Example
#[derive(Debug)]
struct MyHitInfo { triangle_index: u32 }
let hit = HitData::new_with_extra(camera, 1.0, None, None, MyHitInfo { triangle_index: 7 });Trait Implementations
Sourceimpl FromReflect for HitData
impl FromReflect for HitData
Sourcefn from_reflect(reflect: &dyn PartialReflect) -> Option<Self>
fn from_reflect(reflect: &dyn PartialReflect) -> Option<Self>
Self from a reflected value.Sourcefn take_from_reflect(
reflect: Box<dyn PartialReflect>,
) -> Result<Self, Box<dyn PartialReflect>>
fn take_from_reflect( reflect: Box<dyn PartialReflect>, ) -> Result<Self, Box<dyn PartialReflect>>
Self using,
constructing the value using from_reflect if that fails. Read moreSourceimpl GetTypeRegistration for HitData
impl GetTypeRegistration for HitData
Sourcefn get_type_registration() -> TypeRegistration
fn get_type_registration() -> TypeRegistration
TypeRegistration for this type.Sourcefn register_type_dependencies(registry: &mut TypeRegistry)
fn register_type_dependencies(registry: &mut TypeRegistry)
Sourceimpl PartialReflect for HitData
impl PartialReflect for HitData
Sourcefn get_represented_type_info(&self) -> Option<&'static TypeInfo>
fn get_represented_type_info(&self) -> Option<&'static TypeInfo>
Sourcefn try_apply(&mut self, value: &dyn PartialReflect) -> Result<(), ApplyError>
fn try_apply(&mut self, value: &dyn PartialReflect) -> Result<(), ApplyError>
Sourcefn reflect_kind(&self) -> ReflectKind
fn reflect_kind(&self) -> ReflectKind
Sourcefn reflect_ref(&self) -> ReflectRef<'_>
fn reflect_ref(&self) -> ReflectRef<'_>
Sourcefn reflect_mut(&mut self) -> ReflectMut<'_>
fn reflect_mut(&mut self) -> ReflectMut<'_>
Sourcefn reflect_owned(self: Box<Self>) -> ReflectOwned
fn reflect_owned(self: Box<Self>) -> ReflectOwned
Sourcefn try_into_reflect(
self: Box<Self>,
) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
fn try_into_reflect( self: Box<Self>, ) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
Sourcefn try_as_reflect(&self) -> Option<&dyn Reflect>
fn try_as_reflect(&self) -> Option<&dyn Reflect>
Sourcefn try_as_reflect_mut(&mut self) -> Option<&mut dyn Reflect>
fn try_as_reflect_mut(&mut self) -> Option<&mut dyn Reflect>
Sourcefn into_partial_reflect(self: Box<Self>) -> Box<dyn PartialReflect>
fn into_partial_reflect(self: Box<Self>) -> Box<dyn PartialReflect>
Sourcefn as_partial_reflect(&self) -> &dyn PartialReflect
fn as_partial_reflect(&self) -> &dyn PartialReflect
Sourcefn as_partial_reflect_mut(&mut self) -> &mut dyn PartialReflect
fn as_partial_reflect_mut(&mut self) -> &mut dyn PartialReflect
Sourcefn reflect_partial_eq(&self, value: &dyn PartialReflect) -> Option<bool>
fn reflect_partial_eq(&self, value: &dyn PartialReflect) -> Option<bool>
Sourcefn reflect_partial_cmp(&self, value: &dyn PartialReflect) -> Option<Ordering>
fn reflect_partial_cmp(&self, value: &dyn PartialReflect) -> Option<Ordering>
Sourcefn reflect_clone(&self) -> Result<Box<dyn Reflect>, ReflectCloneError>
fn reflect_clone(&self) -> Result<Box<dyn Reflect>, ReflectCloneError>
Self using reflection. Read moreSourcefn apply(&mut self, value: &(dyn PartialReflect + 'static))
fn apply(&mut self, value: &(dyn PartialReflect + 'static))
Sourcefn to_dynamic(&self) -> Box<dyn PartialReflect>
fn to_dynamic(&self) -> Box<dyn PartialReflect>
Sourcefn reflect_clone_and_take<T>(&self) -> Result<T, ReflectCloneError>
fn reflect_clone_and_take<T>(&self) -> Result<T, ReflectCloneError>
PartialReflect, combines reflect_clone and
take in a useful fashion, automatically constructing an appropriate
ReflectCloneError if the downcast fails.Sourcefn reflect_hash(&self) -> Option<u64>
fn reflect_hash(&self) -> Option<u64>
Sourcefn is_dynamic(&self) -> bool
fn is_dynamic(&self) -> bool
Sourceimpl Reflect for HitData
impl Reflect for HitData
Sourcefn as_any_mut(&mut self) -> &mut dyn Any
fn as_any_mut(&mut self) -> &mut dyn Any
&mut dyn Any. Read moreSourcefn into_reflect(self: Box<Self>) -> Box<dyn Reflect>
fn into_reflect(self: Box<Self>) -> Box<dyn Reflect>
Sourcefn as_reflect(&self) -> &dyn Reflect
fn as_reflect(&self) -> &dyn Reflect
Sourcefn as_reflect_mut(&mut self) -> &mut dyn Reflect
fn as_reflect_mut(&mut self) -> &mut dyn Reflect
Sourceimpl Struct for HitData
impl Struct for HitData
Sourcefn field(&self, name: &str) -> Option<&dyn PartialReflect>
fn field(&self, name: &str) -> Option<&dyn PartialReflect>
name as a &dyn PartialReflect.Sourcefn field_mut(&mut self, name: &str) -> Option<&mut dyn PartialReflect>
fn field_mut(&mut self, name: &str) -> Option<&mut dyn PartialReflect>
name as a
&mut dyn PartialReflect.Sourcefn field_at(&self, index: usize) -> Option<&dyn PartialReflect>
fn field_at(&self, index: usize) -> Option<&dyn PartialReflect>
index as a
&dyn PartialReflect.Sourcefn field_at_mut(&mut self, index: usize) -> Option<&mut dyn PartialReflect>
fn field_at_mut(&mut self, index: usize) -> Option<&mut dyn PartialReflect>
index
as a &mut dyn PartialReflect.Sourcefn index_of_name(&self, name: &str) -> Option<usize>
fn index_of_name(&self, name: &str) -> Option<usize>
Sourcefn iter_fields(&self) -> FieldIter<'_>
fn iter_fields(&self) -> FieldIter<'_>
Sourcefn to_dynamic_struct(&self) -> DynamicStruct
fn to_dynamic_struct(&self) -> DynamicStruct
DynamicStruct from this struct.Sourcefn get_represented_struct_info(&self) -> Option<&'static StructInfo>
fn get_represented_struct_info(&self) -> Option<&'static StructInfo>
None if TypeInfo is not available.Sourceimpl TypePath for HitData
impl TypePath for HitData
Sourcefn type_path() -> &'static str
fn type_path() -> &'static str
Sourcefn short_type_path() -> &'static str
fn short_type_path() -> &'static str
Sourcefn type_ident() -> Option<&'static str>
fn type_ident() -> Option<&'static str>
Sourcefn crate_name() -> Option<&'static str>
fn crate_name() -> Option<&'static str>